parser

|  | ## Cheshire3: parser Module

Module parser

Classes | [hide private]
BaseParser |
MinidomParser | Use default Python Minidom implementation to parse document
SaxParser | Default SAX based parser.
LxmlSchemaParser |
LxmlRelaxNGParser |
LxmlParser | lxml based Parser.
FtParser | 4Suite based Parser.
FtSaxParser | 4Suite SAX based Parser.
PassThroughParser | Copy the data from a document (eg list of sax events or a dom tree) into an appropriate record object
MarcParser | Creates MarcRecords which fake the Record API for Marc
XmlRecordStoreParser | Metadata wrapping Parser for RecordStores.